@@ -26,3 +26,19 @@ def set_slug(strategy, user, *args, **kwargs):
 
 def remove_user(strategy, user, *args, **kwargs):
     return {'user': None}
+
+
+@partial
+def set_user_from_kwargs(strategy, *args, **kwargs):
+    if strategy.session_get('attribute'):
+        kwargs['user'].id
+    else:
+        return strategy.redirect(strategy.build_absolute_uri('/attribute'))
+
+
+@partial
+def set_user_from_args(strategy, user, *args, **kwargs):
+    if strategy.session_get('attribute'):
+        user.id
+    else:
+        return strategy.redirect(strategy.build_absolute_uri('/attribute'))
