@@ -2,16 +2,49 @@ import re
 import sys
 import unicodedata
 import collections
-import six
+import functools
+import logging
 
+import six
+import requests
 import social
 
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.poolmanager import PoolManager
+
+from social.exceptions import AuthCanceled, AuthUnreachableProvider
 from social.p3 import urlparse, urlunparse, urlencode, \
                       parse_qs as battery_parse_qs
 
 
 SETTING_PREFIX = 'SOCIAL_AUTH'
 
+social_logger = logging.Logger('social')
+
+
+class SSLHttpAdapter(HTTPAdapter):
+    """"
+    Transport adapter that allows to use any SSL protocol. Based on:
+    http://requests.rtfd.org/latest/user/advanced/#example-specific-ssl-version
+    """
+    def __init__(self, ssl_protocol):
+        self.ssl_protocol = ssl_protocol
+        super(SSLHttpAdapter, self).__init__()
+
+    def init_poolmanager(self, connections, maxsize, block=False):
+        self.poolmanager = PoolManager(
+            num_pools=connections,
+            maxsize=maxsize,
+            block=block,
+            ssl_version=self.ssl_protocol
+        )
+
+    @classmethod
+    def ssl_adapter_session(cls, ssl_protocol):
+        session = requests.Session()
+        session.mount('https://', SSLHttpAdapter(ssl_protocol))
+        return session
+
 
 def import_module(name):
     __import__(name)
@@ -187,3 +220,18 @@ def setting_url(backend, *names):
             value = backend.setting(name)
             if is_url(value):
                 return value
+
+
+def handle_http_errors(func):
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        try:
+            return func(*args, **kwargs)
+        except requests.HTTPError as err:
+            if err.response.status_code == 400:
+                raise AuthCanceled(args[0])
+            elif err.response.status_code == 503:
+                raise AuthUnreachableProvider(args[0])
+            else:
+                raise
+    return wrapper
